@@ -6,6 +6,7 @@ from sqlalchemy.testing.suite import (
     ComponentReflectionTest as _ComponentReflectionTest,
 )
 from sqlalchemy.testing.suite import DateTimeTest as _DateTimeTest
+from sqlalchemy.testing.suite import ExistsTest as _ExistsTest
 from sqlalchemy.testing.suite import (
     ExpandingBoundInTest as _ExpandingBoundInTest,
 )
@@ -15,6 +16,7 @@ from sqlalchemy.testing.suite import JoinTest as _JoinTest
 from sqlalchemy.testing.suite import LikeFunctionsTest as _LikeFunctionsTest
 from sqlalchemy.testing.suite import NumericTest as _NumericTest
 from sqlalchemy.testing.suite import OrderByLabelTest as _OrderByLabelTest
+from sqlalchemy.testing.suite import QuotedNameArgumentTest as _QuotedNameArgumentTest
 from sqlalchemy.testing.suite import TableDDLTest as _TableDDLTest
 
 
@@ -54,6 +56,20 @@ class DateTimeTest(_DateTimeTest):
         return
 
 
+class ExistsTest(_ExistsTest):
+    @pytest.mark.skip()
+    def test_select_exists(cls):
+        # bypass this test because Access ODBC fails with
+        # "SELECT statement includes a reserved word or an argument name ..."
+        return
+
+    @pytest.mark.skip()
+    def test_select_exists_false(cls):
+        # bypass this test because Access ODBC fails with
+        # "SELECT statement includes a reserved word or an argument name ..."
+        return
+
+
 class ExpandingBoundInTest(_ExpandingBoundInTest):
     @pytest.mark.skip()
     def test_null_in_empty_set_is_false(cls):
@@ -188,6 +204,44 @@ class OrderByLabelTest(_OrderByLabelTest):
         return
 
 
+class QuotedNameArgumentTest(_QuotedNameArgumentTest):
+    @pytest.mark.skip()
+    def test_get_table_options(self, name):
+        return
+
+    @pytest.mark.skip()
+    def test_get_view_definition(self, name):
+        return
+
+    @pytest.mark.skip()
+    def test_get_columns(self, name):
+        return
+
+    @pytest.mark.skip()
+    def test_get_pk_constraint(self, name):
+        return
+
+    @pytest.mark.skip()
+    def test_get_foreign_keys(self, name):
+        return
+
+    @pytest.mark.skip()
+    def test_get_indexes(self, name):
+        return
+
+    @pytest.mark.skip()
+    def test_get_unique_constraints(self, name):
+        return
+
+    @pytest.mark.skip()
+    def test_get_table_comment(self, name):
+        return
+
+    @pytest.mark.skip()
+    def test_get_check_constraints(self, name):
+        return
+
+
 class TableDDLTest(_TableDDLTest):
     @pytest.mark.skip()
     def test_create_table_schema(cls):
